Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BuildJobLister ¶
type BuildJobLister interface {
// List lists all BuildJobs in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.BuildJob, err error)
// BuildJobs returns an object that can list and get BuildJobs.
BuildJobs(namespace string) BuildJobNamespaceLister
BuildJobListerExpansion
}
BuildJobLister helps list BuildJobs.
func NewBuildJobLister ¶
func NewBuildJobLister(indexer cache.Indexer) BuildJobLister
NewBuildJobLister returns a new BuildJobLister.
type BuildJobListerExpansion ¶
type BuildJobListerExpansion interface{}
BuildJobListerExpansion allows custom methods to be added to BuildJobLister.
type BuildJobNamespaceLister ¶
type BuildJobNamespaceLister interface {
// List lists all BuildJobs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.BuildJob, err error)
// Get retrieves the BuildJob from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.BuildJob, error)
BuildJobNamespaceListerExpansion
}
BuildJobNamespaceLister helps list and get BuildJobs.
type BuildJobNamespaceListerExpansion ¶
type BuildJobNamespaceListerExpansion interface{}
BuildJobNamespaceListerExpansion allows custom methods to be added to BuildJobNamespaceLister.
Click to show internal directories.
Click to hide internal directories.